@@ -74,8 +74,10 @@ public:
     void requestPointerButtonRelease(quint32 linuxButton);
     void requestPointerMotion(const QSizeF &delta);
     void requestPointerMotionAbsolute(const QPointF &pos);
+    void requestPointerAxis(qreal x, qreal y);
     void requestPointerAxisDiscrete(Qt::Orientation axis, qreal delta);
     void requestKeyboardKeycode(int keycode, bool state);
+    void requestKeyboardKeysym(int keysym, bool state);
     void requestTouchDown(quint32 touchPoint, const QPointF &pos);
     void requestTouchMotion(quint32 touchPoint, const QPointF &pos);
     void requestTouchUp(quint32 touchPoint);
@@ -89,7 +91,7 @@ protected Q_SLOTS:
     void removeOutput(quint32 name);
 
 private:
-    Stream startStreaming(ScreencastingStream *stream, const QString &iconName, const QString &description, const QVariantMap &streamOptions);
+    Stream startStreaming(ScreencastingStream *stream, const QVariantMap &streamOptions);
     bool eventFilter(QObject *watched, QEvent *event) override;
 
     uint m_streamInput = 0;
